@@ -1,26 +1,19 @@
 import numpy as np
 import sympy as sp
 from scipy.sparse.linalg import gmres
-from numba import cuda
-import numba
 import matplotlib.pyplot as plt
 np.set_printoptions(threshold=np.inf)
-import math
-from numba.cuda.random import create_xoroshiro128p_states, xoroshiro128p_uniform_float32
-
+from pyphasefield.field import Field
+from pyphasefield.simulation import Simulation
+from pyphasefield.ppf_utils import COLORMAP_OTHER, COLORMAP_PHASE
+        
 try:
-    #import from within Engines folder
-    from ..field import Field
-    from ..simulation import Simulation
-    from ..ppf_utils import COLORMAP_OTHER, COLORMAP_PHASE
+    from numba import cuda
+    import numba
+    from numba.cuda.random import create_xoroshiro128p_states, xoroshiro128p_uniform_float32
 except:
-    try:
-        #import classes from pyphasefield library
-        from pyphasefield.field import Field
-        from pyphasefield.simulation import Simulation
-        from pyphasefield.ppf_utils import COLORMAP_OTHER, COLORMAP_PHASE
-    except:
-        raise ImportError("Cannot import from pyphasefield library!")
+    import pyphasefield.jit_placeholder as cuda
+    import pyphasefield.jit_placeholder as numba
 
 @cuda.jit(device=True)
 def divagradb(a, axp, axm, ayp, aym, b, bxp, bxm, byp, bym, idx):
@@ -584,11 +577,6 @@ class AnisoDorrGPU(Simulation):
                 c_n = np.zeros(dim)
                 c_n += 0.5
                 self.add_field(c_n, "c_CU", colormap=COLORMAP_OTHER)
-        
-    def initialize_fields_and_imported_data(self):
-        super().initialize_fields_and_imported_data()
-        #initialization of fields/imported data goes below
-        #runs *after* tdb, thermal, fields, and boundary conditions are loaded/initialized
                         
     def just_before_simulating(self):
         super().just_before_simulating()
